@@ -62,7 +62,11 @@ class Parser:
         if tagName.startswith('attr'):
             ob_value = dom.attr('ob')
             if ob_value:
-                value = getattr(self.models, ob_value)
+                arr_index = re.findall(r'.*\[(\d+)\]', ob_value)
+                if len(arr_index) > 0:
+                    value = getattr(self.models, ob_value.replace("[%d]" % arr_index[0], ''))[arr_index]
+                else:
+                    value = getattr(self.models, ob_value)
             else:
                 value = dom.attr('v')
             return self.AttributeObj(tagName.replace('attr-', ''), value, dom)
